summaryrefslogtreecommitdiffstats
path: root/kdejava/koala/org/kde/koala/KDEDesktopMimeType.java
diff options
context:
space:
mode:
Diffstat (limited to 'kdejava/koala/org/kde/koala/KDEDesktopMimeType.java')
-rw-r--r--kdejava/koala/org/kde/koala/KDEDesktopMimeType.java8
1 files changed, 4 insertions, 4 deletions
diff --git a/kdejava/koala/org/kde/koala/KDEDesktopMimeType.java b/kdejava/koala/org/kde/koala/KDEDesktopMimeType.java
index d5b7a18f..be932c01 100644
--- a/kdejava/koala/org/kde/koala/KDEDesktopMimeType.java
+++ b/kdejava/koala/org/kde/koala/KDEDesktopMimeType.java
@@ -67,18 +67,18 @@ public class KDEDesktopMimeType extends KMimeType {
*/
// TQValueList<KDEDesktopMimeType::Service> userDefinedServices(const TQString& arg1,bool arg2); >>>> NOT CONVERTED
/**
- Overload of userDefinedServices for speed purposes: it takes a KConfig so that
+ Overload of userDefinedServices for speed purposes: it takes a TDEConfig so that
the caller can check things in the file without having it parsed twice.
- @short Overload of userDefinedServices for speed purposes: it takes a KConfig so that the caller can check things in the file without having it parsed twice.
+ @short Overload of userDefinedServices for speed purposes: it takes a TDEConfig so that the caller can check things in the file without having it parsed twice.
*/
- // TQValueList<KDEDesktopMimeType::Service> userDefinedServices(const TQString& arg1,KConfig& arg2,bool arg3); >>>> NOT CONVERTED
+ // TQValueList<KDEDesktopMimeType::Service> userDefinedServices(const TQString& arg1,TDEConfig& arg2,bool arg3); >>>> NOT CONVERTED
/**
Overload of userDefinedServices but also allows you to pass a list of urls for this file.
This allows for the menu to be changed depending on the exact files via
the X-TDE-GetActionMenu extension.
@short Overload of userDefinedServices but also allows you to pass a list of urls for this file.
*/
// TQValueList<KDEDesktopMimeType::Service> userDefinedServices(const TQString& arg1,KConfig& arg2,bool arg3,const KURL::List& arg4); >>>> NOT CONVERTED
/**
Execute <code>service</code> on the list of <code>urls.</code>
@param urls the list of urls
@@ -67,18 +67,18 @@ public class KDEDesktopMimeType extends KMimeType {
*/
- // TQValueList<KDEDesktopMimeType::Service> userDefinedServices(const TQString& arg1,KConfig& arg2,bool arg3,const KURL::List& arg4); >>>> NOT CONVERTED
+ // TQValueList<KDEDesktopMimeType::Service> userDefinedServices(const TQString& arg1,TDEConfig& arg2,bool arg3,const KURL::List& arg4); >>>> NOT CONVERTED
/**
Execute <code>service</code> on the list of <code>urls.</code>